pub struct OwnedEvent { /* private fields */ }Expand description
Owned metadata-aware event data.
This is useful for detached events, MPI fetches, and Python-owned event objects. Use
OwnedEvent::as_event to evaluate variables and amplitudes through the standard borrowed
Event interface.
Implementations
Sourceimpl OwnedEvent
impl OwnedEvent
Sourcepub fn new(event: Arc<EventData>, metadata: Arc<DatasetMetadata>) -> Self
pub fn new(event: Arc<EventData>, metadata: Arc<DatasetMetadata>) -> Self
Create a new metadata-aware event from raw data and dataset metadata.
Sourcepub fn as_event(&self) -> Event<'_>
pub fn as_event(&self) -> Event<'_>
Borrow this owned row as an Event suitable for variable and amplitude evaluation.
Sourcepub fn p4s(&self) -> IndexMap<&str, Vec4>
pub fn p4s(&self) -> IndexMap<&str, Vec4>
Return the four-momenta stored in this event keyed by their registered names.
Sourcepub fn aux(&self) -> IndexMap<&str, f64>
pub fn aux(&self) -> IndexMap<&str, f64>
Return the auxiliary scalars stored in this event keyed by their registered names.
Sourcepub fn metadata(&self) -> &DatasetMetadata
pub fn metadata(&self) -> &DatasetMetadata
Retrieve the dataset metadata attached to this event.
Sourcepub fn metadata_arc(&self) -> Arc<DatasetMetadata>
pub fn metadata_arc(&self) -> Arc<DatasetMetadata>
Clone the metadata handle associated with this event.
Sourcepub fn p4(&self, name: &str) -> Option<Vec4>
pub fn p4(&self, name: &str) -> Option<Vec4>
Retrieve a four-momentum (or aliased sum) by name.
Sourcepub fn get_p4_sum<N>(&self, names: N) -> Vec4
pub fn get_p4_sum<N>(&self, names: N) -> Vec4
Return a four-momentum formed by summing four-momenta with the specified names.
Sourcepub fn boost_to_rest_frame_of<N>(&self, names: N) -> EventData
pub fn boost_to_rest_frame_of<N>(&self, names: N) -> EventData
Boost all four-momenta into the rest frame defined by the specified particle names.
Methods from Deref<Target = EventData>
Sourcepub fn get_p4_sum<T: AsRef<[usize]>>(&self, indices: T) -> Vec4
pub fn get_p4_sum<T: AsRef<[usize]>>(&self, indices: T) -> Vec4
Return a four-momentum from the sum of four-momenta at the given indices in the EventData.
Sourcepub fn boost_to_rest_frame_of<T: AsRef<[usize]>>(&self, indices: T) -> Self
pub fn boost_to_rest_frame_of<T: AsRef<[usize]>>(&self, indices: T) -> Self
Boost all the four-momenta in the EventData to the rest frame of the given set of
four-momenta by indices.