pub struct CompiledExpression { /* private fields */ }Expand description
Tree-like diagnostic view of the compiled expression DAG.
The compiled expression is a directed acyclic graph because common subexpressions can be
deduplicated during compilation. The display format expands the graph from the root once and
marks later visits to the same node with (ref).
Implementations