pub struct AllowedPartialWave {
pub wave: PartialWave,
pub parity: Option<Parity>,
pub c_parity: Option<Parity>,
}Expand description
A partial wave together with allowed parity and C-parity, if applicable.
Fields
wave: PartialWaveThe angular quantum numbers of the wave
parity: Option<Parity>The allowed parity, if applicable
c_parity: Option<Parity>The allowed C-parity, if applicable
Implementations
Sourceimpl AllowedPartialWave
impl AllowedPartialWave
Sourcepub fn new(
wave: PartialWave,
daughters: (&ParticleProperties, &ParticleProperties),
) -> Self
pub fn new( wave: PartialWave, daughters: (&ParticleProperties, &ParticleProperties), ) -> Self
Take an existing PartialWave and infer parity and C-parity from its decay products.
Sourcepub fn infer_parity(
daughters: (&ParticleProperties, &ParticleProperties),
l: OrbitalAngularMomentum,
) -> Option<Parity>
pub fn infer_parity( daughters: (&ParticleProperties, &ParticleProperties), l: OrbitalAngularMomentum, ) -> Option<Parity>
Infer the parity of a state given the parity of its decay products and its orbital angular momentum.
Sourcepub fn infer_c_parity(
daughters: (&ParticleProperties, &ParticleProperties),
l: OrbitalAngularMomentum,
s: AngularMomentum,
) -> Option<Parity>
pub fn infer_c_parity( daughters: (&ParticleProperties, &ParticleProperties), l: OrbitalAngularMomentum, s: AngularMomentum, ) -> Option<Parity>
Infer the C-parity of a state given the species of its decay products, its orbital angular momentum, and its intrinsic spin.