pub struct Charge(/* private fields */);Expand description
Electric charge store as three times its physical value.
Because quarks may have fractional charge, we represent a charge of +1 using the value 3, a
charge of +2/3 by 2, and so on.
Implementations
Sourceimpl Charge
impl Charge
Sourcepub const fn third_integer(value: i32) -> Self
pub const fn third_integer(value: i32) -> Self
Construct a signed charge from a numerator over three.
Sourcepub const fn is_integer(self) -> bool
pub const fn is_integer(self) -> bool
Return whether this quantum number represents an integer value.