pub struct PartialWave {
pub j: AngularMomentum,
pub l: OrbitalAngularMomentum,
pub s: AngularMomentum,
pub label: String,
}Expand description
A partial wave defined by a total angular momentum, J, an orbital angular momentum, L, and
and intrinsic spin, S.
Fields
j: AngularMomentumThe total angular momentum of the wave
l: OrbitalAngularMomentumThe orbital angular momentum of the wave
s: AngularMomentumThe spin of the wave
label: StringThe spectroscopic label of the wave
Implementations
Sourceimpl PartialWave
impl PartialWave
Sourcepub fn new(
j: AngularMomentum,
l: OrbitalAngularMomentum,
s: AngularMomentum,
) -> LadduResult<Self>
pub fn new( j: AngularMomentum, l: OrbitalAngularMomentum, s: AngularMomentum, ) -> LadduResult<Self>
Construct a new partial wave from the given angular momentum quantum numbers.
Sourcepub fn with_label(self, label: impl Into<String>) -> Self
pub fn with_label(self, label: impl Into<String>) -> Self
Set the spectroscopic label of the wave.
Sourcepub fn validate_coupling(
j: AngularMomentum,
l: OrbitalAngularMomentum,
s: AngularMomentum,
) -> LadduResult<()>
pub fn validate_coupling( j: AngularMomentum, l: OrbitalAngularMomentum, s: AngularMomentum, ) -> LadduResult<()>
Validate the set of angular momentum quantum numbers which define a partial wave.