ParticleProperties

Struct ParticleProperties 

pub struct ParticleProperties {
Show 19 fields pub name: Option<String>, pub species: Option<String>, pub antiparticle_species: Option<String>, pub self_conjugate: Option<bool>, pub spin: Option<AngularMomentum>, pub parity: Option<Parity>, pub c_parity: Option<Parity>, pub g_parity: Option<Parity>, pub charge: Option<Charge>, pub isospin: Option<Isospin>, pub strangeness: Option<i32>, pub charm: Option<i32>, pub bottomness: Option<i32>, pub topness: Option<i32>, pub baryon_number: Option<i32>, pub electron_lepton_number: Option<i32>, pub muon_lepton_number: Option<i32>, pub tau_lepton_number: Option<i32>, pub statistics: Option<Statistics>,
}
The set of properties which define the quantum state of a particle.

Fields

name: Option<String>

The name of the particle, if known.

species: Option<String>

The species of the particle, if known (used to compare to ParticleProperties::antiparticle_species).

antiparticle_species: Option<String>

The species of the particle’s antiparticle, if known (used to compare to ParticleProperties::species).

self_conjugate: Option<bool>

Whether the particle is its own antiparticle.

spin: Option<AngularMomentum>

The spin of the particle, if known.

parity: Option<Parity>

The intrinsic parity of the particle, if known.

c_parity: Option<Parity>

The intrinsic C-parity of the particle, if known or applicable.

g_parity: Option<Parity>

The intrinsic G-parity of the particle, if known or applicable.

charge: Option<Charge>

The electric charge of the particle, if known.

isospin: Option<Isospin>

The isospin of the particle, if known.

strangeness: Option<i32>

The total strangeness of the particle, if known.

charm: Option<i32>

The total charm of the particle, if known.

bottomness: Option<i32>

The total bottomness of the particle, if known.

topness: Option<i32>

The total topness of the particle, if known.

baryon_number: Option<i32>

The total baryon number of the particle, if known.

electron_lepton_number: Option<i32>

The electron lepton number of the particle, if known.

muon_lepton_number: Option<i32>

The muon lepton number of the particle, if known.

tau_lepton_number: Option<i32>

The tau lepton number of the particle, if known.

statistics: Option<Statistics>

The particle’s statistical nature, if known.

Implementations

Source

impl ParticleProperties

pub fn name(&self) -> LadduResult<String>

Get the particle’s name

Returns an error if this property is not known.

pub fn species(&self) -> LadduResult<String>

Get the particle’s species

Returns an error if this property is not known.

pub fn antiparticle_species(&self) -> LadduResult<String>

Get the particle’s antiparticle species

Returns an error if this property is not known.

pub fn self_conjugate(&self) -> LadduResult<bool>

Get the particle’s self-conjugate status

Returns an error if this property is not known.

pub fn spin(&self) -> LadduResult<AngularMomentum>

Get the particle’s spin

Returns an error if this property is not known.

pub fn parity(&self) -> LadduResult<Parity>

Get the particle’s intrinsic parity

Returns an error if this property is not known.

pub fn c_parity(&self) -> LadduResult<Parity>

Get the particle’s intrinsic C-parity

Returns an error if this property is not known.

pub fn g_parity(&self) -> LadduResult<Parity>

Get the particle’s intrinsic G-parity

Returns an error if this property is not known.

pub fn charge(&self) -> LadduResult<Charge>

Get the particle’s electric charge

Returns an error if this property is not known.

pub fn isospin(&self) -> LadduResult<Isospin>

Get the particle’s isospin

Returns an error if this property is not known.

pub fn strangeness(&self) -> LadduResult<i32>

Get the particle’s strangeness

Returns an error if this property is not known.

pub fn charm(&self) -> LadduResult<i32>

Get the particle’s charm

Returns an error if this property is not known.

pub fn bottomness(&self) -> LadduResult<i32>

Get the particle’s bottomness

Returns an error if this property is not known.

pub fn topness(&self) -> LadduResult<i32>

Get the particle’s topness

Returns an error if this property is not known.

pub fn baryon_number(&self) -> LadduResult<i32>

Get the particle’s baryon number

Returns an error if this property is not known.

pub fn electron_lepton_number(&self) -> LadduResult<i32>

Get the particle’s electron lepton number

Returns an error if this property is not known.

pub fn muon_lepton_number(&self) -> LadduResult<i32>

Get the particle’s muon lepton number

Returns an error if this property is not known.

pub fn tau_lepton_number(&self) -> LadduResult<i32>

Get the particle’s tau lepton number

Returns an error if this property is not known.

pub fn statistics(&self) -> LadduResult<Statistics>

Get the particle’s statistics

Returns an error if this property is not known.

pub fn unknown() -> Self

Construct a particle with no specified properties.

pub fn jp(j: AngularMomentum, p: Parity) -> Self

Construct a particle with the given spin and parity.

pub fn jpc(j: AngularMomentum, p: Parity, c: Parity) -> Self

Construct a particle with the given spin, parity, and C-parity.

pub fn with_name(self, name: impl Into<String>) -> Self

Set the particle’s name.

pub fn with_species(self, species: impl Into<String>) -> Self

Set the particle’s species.

pub fn with_antiparticle_species( self, antiparticle_species: impl Into<String>, ) -> Self

Set the particle’s antiparticle species.

pub fn with_self_conjugate(self, value: bool) -> Self

Set whether the particle is its own antiparticle.

pub fn with_spin(self, j: AngularMomentum) -> Self

Set the particle’s spin.

pub fn with_parity(self, p: Parity) -> Self

Set the particle’s intrinsic parity.

pub fn with_c_parity(self, c: Parity) -> Self

Set the particle’s intrinsic C-parity.

pub fn with_g_parity(self, g: Parity) -> Self

Set the particle’s intrinsic G-parity.

pub fn with_charge(self, q: Charge) -> Self

Set the particle’s electric charge.

pub fn with_isospin(self, isospin: Isospin) -> Self

Set the particle’s isospin state.

pub fn with_strangeness(self, s: i32) -> Self

Set the particle’s total strangeness.

pub fn with_charm(self, c: i32) -> Self

Set the particle’s total charm.

pub fn with_bottomness(self, b: i32) -> Self

Set the particle’s total bottomness.

pub fn with_topness(self, t: i32) -> Self

Set the particle’s total topness.

pub fn with_baryon_number(self, b: i32) -> Self

Set the particle’s total baryon number.

pub fn with_electron_lepton_number(self, e: i32) -> Self

Set the particle’s electron lepton number.

pub fn with_muon_lepton_number(self, m: i32) -> Self

Set the particle’s muon lepton number.

pub fn with_tau_lepton_number(self, t: i32) -> Self

Set the particle’s tau lepton number.

pub fn with_statistics(self, s: Statistics) -> LadduResult<Self>

Set the particle’s statistical nature.

Returns an error if the spin and statistics do not match.

pub fn is_antiparticle_of(&self, other: &ParticleProperties) -> bool

Returns true if self is the antiparticle of other.