pub struct Particle { /* private fields */ }Expand description
A kinematic particle or composite system used to define a reaction.
Implementations
Sourceimpl Particle
impl Particle
Sourcepub fn stored(id: impl Into<String>) -> Self
pub fn stored(id: impl Into<String>) -> Self
Construct a stored particle backed by a dataset p4 column with the same identifier.
Sourcepub fn fixed(label: impl Into<String>, p4: Vec4) -> Self
pub fn fixed(label: impl Into<String>, p4: Vec4) -> Self
Construct a particle with a fixed four-momentum.
Sourcepub fn missing(label: impl Into<String>) -> Self
pub fn missing(label: impl Into<String>) -> Self
Construct a missing particle solved by the enclosing reaction topology.
Sourcepub fn composite(
label: impl Into<String>,
daughters: (&Particle, &Particle),
) -> LadduResult<Self>
pub fn composite( label: impl Into<String>, daughters: (&Particle, &Particle), ) -> LadduResult<Self>
Construct a composite particle from exactly two ordered daughter particles.
Sourcepub const fn source(&self) -> &ParticleSource
pub const fn source(&self) -> &ParticleSource
Return the particle four-momentum source.
Sourcepub const fn is_missing(&self) -> bool
pub const fn is_missing(&self) -> bool
Return whether this particle is missing.