pub struct ParticleGraph { /* private fields */ }Expand description
Owned particle definitions and decay edges for a reaction.
Implementations
Sourceimpl ParticleGraph
impl ParticleGraph
Sourcepub fn new(roots: impl IntoIterator<Item = Particle>) -> LadduResult<Self>
pub fn new(roots: impl IntoIterator<Item = Particle>) -> LadduResult<Self>
Construct a particle graph from root particles.
Sourcepub fn particle(&self, particle: &str) -> LadduResult<&Particle>
pub fn particle(&self, particle: &str) -> LadduResult<&Particle>
Return the particle with the given identifier.
Sourcepub fn contains(&self, particle: &str) -> bool
pub fn contains(&self, particle: &str) -> bool
Return whether the graph contains a particle with the given identifier.
Sourcepub fn particles(&self) -> Vec<&Particle>
pub fn particles(&self) -> Vec<&Particle>
Return all particle definitions in graph traversal order.
Sourcepub fn root_containing(&self, particle: &str) -> Option<&Particle>
pub fn root_containing(&self, particle: &str) -> Option<&Particle>
Return the graph root containing the particle identifier.